pitchtools.apply_accidental_to_named_chromatic_pitch
====================================================

.. autofunction:: abjad.tools.pitchtools.apply_accidental_to_named_chromatic_pitch.apply_accidental_to_named_chromatic_pitch
